import React from 'react';
import { FieldValues, RegisterOptions, SubmitHandler, UseFormReturn } from 'react-hook-form';
export type FormProps<T extends FieldValues> = {
    form?: UseFormReturn<T, any>;
    onSubmit: SubmitHandler<T>;
    children: React.ReactNode;
    debug?: boolean;
} & Omit<React.HTMLAttributes<HTMLFormElement>, 'onSubmit'>;
/**
 * Renders a form component managed by `react-hook-form`. Its children should be components controlled by `react-hook-form`.
 * @param form - value returned by `useForm`, if unspecified a default useform instance is used
 * @param onSubmit - callback for when form is submitted
 * @param children - components to render within the form
 * @returns
 */
declare function Form<T extends FieldValues>({ form, onSubmit, children, debug, ...rest }: FormProps<T>): JSX.Element;
declare namespace Form {
    var Item: ({ name, children, label, rules, setValueAs, ...rest }: FormItemProps) => JSX.Element;
}
/**
 * Contains information about the form item
 */
export declare const FormItemProvider: ({ children, rules, name, setValueAs, }: {
    children: React.ReactNode;
    rules: RegisterOptions;
    name: string;
    setValueAs: FormItemProps['setValueAs'];
}) => JSX.Element;
/**
 * Returns the form item config
 */
export declare const useFormItem: () => import("./context").FormItemContext;
export interface FormItemProps extends React.HTMLAttributes<HTMLDivElement> {
    children: React.ReactNode;
    /**
     * Label text, can either be a string or a custom component.
     */
    label: React.ReactNode | string;
    /**
     * Name of the input associated with this item
     */
    name: string;
    /**
     * (Optional) Description of the input required
     */
    description?: string;
    /**
     * Validation rules for the Form item's children
     */
    rules?: RegisterOptions;
    /**
     * If defined, can be used to transform value before it's saved to the form
     */
    setValueAs?: (value: string) => any;
}
export default Form;
